package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (q *Queue) Destroy()
Destory 销毁队列对象
PopMany 从队列头部弹出多个元素(单个消费者)
func (q *Queue) Push(item interface{})
Push 向队列尾部插入一个元素
Source Files
¶
Click to show internal directories.
Click to hide internal directories.