package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Queue 表示队列对象
func (q *Queue) Destroy()
Destory 销毁队列对象
func (q *Queue) Pop() interface{}
Pop 从队列头部弹出一个元素
func (q *Queue) Push(x interface{})
Push 向队列尾部插入一个元素
Source Files
¶
Click to show internal directories.
Click to hide internal directories.